/*

    LCSMessengerHistory.nsi

    Copyright (C) 2007 Darrin M. Gorski

    This file is part of LCSMessengerHistory.

    LCSMessengerHistory is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 3 of the License, or
    (at your option) any later version.

    LCSMessengerHistory is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.



    This installer script is for use with NSIS Installation packager tool
    available at http://nsis.sourceforge.net/

*/


;--------------------------------
;Include Modern UI

!include "MUI.nsh"


;--------------------------------
;General

; The name of the installer
Name "LCSMessengerHistory"

; The file to write
OutFile "LCSMessengerHistorySetup.exe"

; The default installation directory
InstallDir $PROGRAMFILES\LCSMessengerHistory

; Registry key to check for directory (so if you install again, it will 
; overwrite the old one automatically)
InstallDirRegKey HKLM "Software\Darrin M. Gorski\LCSMessengerHistory" "Install_Dir"

; setup.exe icon resources
!define MUI_ICON "hdd-chat-install.ico"
!define MUI_UNICON "hdd-chat-uninstall.ico"


;--------------------------------
; MUI Interface settings

!define MUI_ABORTWARNING
!define MUI_WELCOMEPAGE_TITLE_3LINES
!define MUI_FINISHPAGE_TITLE_3LINES


;--------------------------------
; installer exe version info

VIProductVersion "2.3.0.0"
VIAddVersionKey "ProductName" "LCSMessengerHistory"
VIAddVersionKey "ProductVersion" "2.3.0.0"
VIAddVersionKey "InternalName" "LCSMessengerHistorySetup.exe"
VIAddVersionKey "OriginalName" "LCSMessengerHistorySetup.exe"
VIAddVersionKey "Comments" "An auto-save chat history app for Communicator"
VIAddVersionKey "CompanyName" "gorski.net"
;;VIAddVersionKey "LegalTrademarks" "Test Application is a trademark of Fake company"
VIAddVersionKey "LegalCopyright" " Darrin M. Gorski"
VIAddVersionKey "FileDescription" "LCSMessengerHistory Installer"
VIAddVersionKey "FileVersion" "2.3.0.0"



;--------------------------------
; Pages

!insertmacro MUI_PAGE_WELCOME
!insertmacro MUI_PAGE_LICENSE "..\LICENSE.txt"
!insertmacro MUI_PAGE_COMPONENTS
!insertmacro MUI_PAGE_DIRECTORY
!insertmacro MUI_PAGE_INSTFILES
!insertmacro MUI_PAGE_FINISH

!insertmacro MUI_UNPAGE_WELCOME
!insertmacro MUI_UNPAGE_INSTFILES
!insertmacro MUI_UNPAGE_FINISH


;--------------------------------
; MUI Language

!insertmacro MUI_LANGUAGE "English"


;--------------------------------


; The stuff to install, cannot be deselected

Section "LCSMessengerHistory" MainApp

  SectionIn RO
  
  ; Set output path to the installation directory.
  SetOutPath $INSTDIR
  
  File "..\LCSMessengerHistory\bin\Release\LCSMessengerHistory.exe"
  File "..\LCSMessengerHistory\bin\Release\Interop.CommunicatorAPI.dll"
  File "..\README.txt"
  File "..\CHANGELOG.txt"
  File "..\LICENSE.txt"

  ; Write the installation path into the registry
  WriteRegStr HKLM "SOFTWARE\Darrin M. Gorski\LCSMessengerHistory" "Install_Dir" "$INSTDIR"
  
  ; Write the uninstall keys for Windows
  WriteRegStr HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\LCSMessengerHistory" "DisplayName" "LCSMessengerHistory"
  WriteRegStr HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\LCSMessengerHistory" "UninstallString" '"$INSTDIR\uninstall.exe"'
  WriteRegDWORD HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\LCSMessengerHistory" "NoModify" 1
  WriteRegDWORD HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\LCSMessengerHistory" "NoRepair" 1
  WriteUninstaller "uninstall.exe"
  
SectionEnd


Section "Start Menu Shortcuts" ShortCuts

  CreateDirectory "$SMPROGRAMS\LCSMessengerHistory"
  CreateShortCut "$SMPROGRAMS\LCSMessengerHistory\LCSMessengerHistory.lnk" "$INSTDIR\LCSMessengerHistory.exe" "" "$INSTDIR\LCSMessengerHistory.exe" 0
  CreateShortCut "$SMPROGRAMS\LCSMessengerHistory\README.lnk" "$INSTDIR\README.txt" "" "$INSTDIR\README.txt" 0
  CreateShortCut "$SMPROGRAMS\LCSMessengerHistory\LICENSE.lnk" "$INSTDIR\LICENSE.txt" "" "$INSTDIR\LICENSE.txt" 0
  CreateShortCut "$SMPROGRAMS\LCSMessengerHistory\Uninstall.lnk" "$INSTDIR\uninstall.exe" "" "$INSTDIR\uninstall.exe" 0
  
SectionEnd


Section "Startup Shortcut" StartupShortCut

  CreateShortCut "$SMSTARTUP\LCSMessengerHistory.lnk" "$INSTDIR\LCSMessengerHistory.exe" "" "$INSTDIR\LCSMessengerHistory.exe" 0
  
SectionEnd


Section "-Start App"

  MessageBox MB_YESNO|MB_ICONQUESTION "Start up the LCSMessengerHistory app now?" /SD IDYES IDNO SkipExec
  Exec '"$INSTDIR\LCSMessengerHistory.exe"'
  SkipExec:

  MessageBox MB_YESNO|MB_ICONQUESTION "Would you like to view the README file now?" /SD IDNO IDNO SkipReadme
  ExecShell "open" '"$INSTDIR\README.txt"'
  SkipReadme:


SectionEnd


;--------------------------------
;Descriptions

  ;Language strings
  LangString DESC_MainApp ${LANG_ENGLISH} "LCSMessengerHistory application program files (required)"
  LangString DESC_ShortCuts ${LANG_ENGLISH} "Add Start Menu folder and shortcuts for the LCSMessengerHistory application"
  LangString DESC_StartupShortCut ${LANG_ENGLISH} "Add a shortcut to your Startup folder so that LCSMessengerHistory runs automatically when Windows starts up."

  ;Assign language strings to sections
  !insertmacro MUI_FUNCTION_DESCRIPTION_BEGIN
    !insertmacro MUI_DESCRIPTION_TEXT ${MainApp} $(DESC_MainApp)
    !insertmacro MUI_DESCRIPTION_TEXT ${ShortCuts} $(DESC_ShortCuts)
    !insertmacro MUI_DESCRIPTION_TEXT ${StartupShortCut} $(DESC_StartupShortCut)
  !insertmacro MUI_FUNCTION_DESCRIPTION_END


;--------------------------------

; Uninstaller

Section "Uninstall"

  ; first remove program file, will fail if it's running

  ClearErrors
  Delete "$INSTDIR\LCSMessengerHistory.exe"
  IfErrors 0 +3
    MessageBox MB_OK|MB_ICONEXCLAMATION "Unable to uninstall the LCSMessengerHistory app.  Please make sure the app is not running and try again."
    Quit
  
  Delete "$INSTDIR\Interop.CommunicatorAPI.dll"
  Delete "$INSTDIR\README.txt"
  Delete "$INSTDIR\CHANGELOG.txt"
  Delete "$INSTDIR\LICENSE.txt"
  Delete "$INSTDIR\uninstall.exe"

  ; Remove shortcuts, if any
  Delete "$SMPROGRAMS\LCSMessengerHistory\*.*"
  Delete "$SMSTARTUP\LCSMessengerHistory.lnk"

  ; Remove directories used
  RMDir "$SMPROGRAMS\LCSMessengerHistory"
  RMDir "$INSTDIR"

  ; Remove registry keys
  DeleteRegKey HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\LCSMessengerHistory"
  DeleteRegKey HKLM "SOFTWARE\Darrin M. Gorski\LCSMessengerHistory"

SectionEnd


;; make sure only one copy of this installer is running at a time
Function .onInit
 System::Call 'kernel32::CreateMutexA(i 0, i 0, t "LCSMHSetupMutex") i .r1 ?e'
 Pop $R0
 
 StrCmp $R0 0 +3
   MessageBox MB_OK|MB_ICONEXCLAMATION "The LCSMessengerHistory installer is already running."
   Abort
FunctionEnd

